supabase_realtime library
Client library for Supabase Realtime: subscribe to PostgreSQL database changes, broadcast messages, and presence over a websocket connection.
Classes
- PostgresChangeFilter
- Creates a filter for realtime postgres change listener.
- PostgresChangePayload
- Data class that contains the Postgres change event payload.
- PostgresColumn
- Presence
- A single shared state between users with Realtime Presence.
- RealtimeChannel
- RealtimeChannelConfig
- RealtimeClient
- Manages a persistent WebSocket connection to the Supabase Realtime server.
- RealtimeCloseEvent
- Event details for when the connection closed.
- RealtimeConnectionStatusChange
- A connection status change emitted by RealtimeClient.onStatusChange.
- RealtimeConstants
- RealtimeMessage
- A message as it travels over the Realtime WebSocket connection.
- RealtimePresenceJoinPayload
- Payload for PresenceEvent.join callback.
- RealtimePresenceLeavePayload
- Payload for PresenceEvent.leave callback.
- RealtimePresencePayload
- Base class for the payloads emitted by the presence streams.
- RealtimePresenceSyncPayload
- Payload for PresenceEvent.sync callback.
- RealtimeSubscribeStatusChange
- A subscription status change emitted by RealtimeChannel.onStatusChange.
- RealtimeSystemPayload
-
Payload of a
systemevent emitted by the server. - ReplayOption
- Configuration for broadcast replay feature. Allows replaying broadcast messages from a specific timestamp.
- SinglePresenceState
- A single client connected through presence.
Enums
- ChannelResponse
- PostgresChangeEvent
- PostgresChangeFilterType
- Specifies the type of filter to be applied on realtime Postgres Change listener.
- PostgresType
- PresenceEvent
- RealtimeConnectionStatus
- The status of the WebSocket connection reported by RealtimeClient.onStatusChange.
- RealtimeHeartbeatStatus
- The lifecycle status of a heartbeat reported to RealtimeClient.onHeartbeat.
- RealtimeLogLevel
- RealtimeProtocolVersion
- RealtimeSubscribeStatus
- SocketState
Typedefs
-
RealtimeDecode
= Future<
RealtimeMessage> Function(Object frame) -
Deserializes a raw incoming WebSocket frame (
Stringor binary) into a message. -
RealtimeEncode
= Future<
Object> Function(RealtimeMessage message) -
Serializes an outgoing message into the
Stringor binary frame written to the WebSocket. -
WebSocketTransport
= WebSocketChannel Function(String url, Map<
String, String> headers)